"""
    ICA Rest API

    This API can be used to interact with Illumina Connected Analytics.<br> <h2>Authentication</h2> <p> Authentication to the  API can be done in multiple ways:<br> <ul><li>For the entire API, except for the POST /tokens endpoint: API-key + JWT</li> <li>Only for the POST /tokens endpoint: API-key + Basic Authentication</li></ul> </p> <p> <h4>API-key</h4> API keys are managed within the Illumina portal where you can manage your profile after you have logged on. The API-key has to be provided in the X-API-Key header parameter when executing API calls to ICA. In the background, a JWT will be requested at the IDP of Illumina to create a session. A good practice is to not use the API-key for every API call, but to first generate a JWT and to use that for authentication in subsequent calls.<br> </p> <p> <h4>JWT</h4> To avoid using an API-key for each call, we recommend to request a JWT via the POST /tokens endpoint  using this API-key. The JWT will expire after a pre-configured period specified by a tenant administrator through the IAM console in the Illumina portal. The JWT is the preferred way for authentication.<br>A not yet expired, still valid JWT could be refreshed using the POST /tokens:refresh endpoint.<br>Refreshing the JWT is not possible if the JWT was generated by using an API-key.<br> </p> <p> <h4>Basic Authentication</h4> Basic authentication is only supported by the POST /tokens endpoint for generating a JWT. Use \"Basic base64encoded(emailaddress:password)\" in the \"Authorization\" header parameter for this authentication method. In case having access to multiple tenants using the same email-address, also provide the \"tenant\" request parameter to indicate what tenant you would like to request a JWT for. </p> <p> <h2>Compression</h2> If the API client provides request header 'Accept-Encoding' with value 'gzip', then the API applies GZIP compression on the JSON response. This significantly reduces the size and thus the download time of the response, which results in faster end-to-end API calls. In case of compression, the API also provides response header 'Content-Encoding' with value 'gzip', as indication for the client that decompression is required. </p>   # noqa: E501

    The version of the OpenAPI document: 3
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from libica.openapi.v2.api_client import ApiClient, Endpoint as _Endpoint
from libica.openapi.v2.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from libica.openapi.v2.model.input_parameter_list import InputParameterList
from libica.openapi.v2.model.links import Links
from libica.openapi.v2.model.pipeline_configuration_parameter_list import PipelineConfigurationParameterList
from libica.openapi.v2.model.pipeline_file import PipelineFile
from libica.openapi.v2.model.pipeline_file_list import PipelineFileList
from libica.openapi.v2.model.pipeline_html_documentation import PipelineHtmlDocumentation
from libica.openapi.v2.model.problem import Problem
from libica.openapi.v2.model.project_pipeline import ProjectPipeline
from libica.openapi.v2.model.project_pipeline_list import ProjectPipelineList
from libica.openapi.v2.model.reference_set_list import ReferenceSetList


class ProjectPipelineApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_cwl_pipeline_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectPipeline,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines:createCwlPipeline',
                'operation_id': 'create_cwl_pipeline',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'code',
                    'description',
                    'workflow_cwl_file',
                    'parameters_xml_file',
                    'analysis_storage_id',
                    'tool_cwl_files',
                    'metadata_model_file',
                    'links',
                    'version_comment',
                    'categories',
                    'html_documentation',
                    'proprietary',
                ],
                'required': [
                    'project_id',
                    'code',
                    'description',
                    'workflow_cwl_file',
                    'parameters_xml_file',
                    'analysis_storage_id',
                ],
                'nullable': [
                    'metadata_model_file',
                    'links',
                    'version_comment',
                    'categories',
                    'html_documentation',
                    'proprietary',
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                    'description',
                    'categories',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 255,
                        'min_length': 1,
                        'regex': {
                            'pattern': r'^[a-zA-Z0-9 _-]*(\/[a-zA-Z0-9 _-]+)*$',  # noqa: E501
                        },
                    },
                    ('description',): {
                        'max_length': 4000,
                        'min_length': 1,
                    },
                    ('categories',): {

                        'max_items': 4000,
                        'min_items': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'code':
                        (str,),
                    'description':
                        (str,),
                    'workflow_cwl_file':
                        (file_type,),
                    'parameters_xml_file':
                        (file_type,),
                    'analysis_storage_id':
                        (str,),
                    'tool_cwl_files':
                        ([file_type],),
                    'metadata_model_file':
                        (file_type, none_type,),
                    'links':
                        (Links,),
                    'version_comment':
                        (str, none_type,),
                    'categories':
                        ([str, none_type], none_type,),
                    'html_documentation':
                        (str, none_type,),
                    'proprietary':
                        (bool, none_type,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'code': 'code',
                    'description': 'description',
                    'workflow_cwl_file': 'workflowCwlFile',
                    'parameters_xml_file': 'parametersXmlFile',
                    'analysis_storage_id': 'analysisStorageId',
                    'tool_cwl_files': 'toolCwlFiles',
                    'metadata_model_file': 'metadataModelFile',
                    'links': 'links',
                    'version_comment': 'versionComment',
                    'categories': 'categories',
                    'html_documentation': 'htmlDocumentation',
                    'proprietary': 'proprietary',
                },
                'location_map': {
                    'project_id': 'path',
                    'code': 'form',
                    'description': 'form',
                    'workflow_cwl_file': 'form',
                    'parameters_xml_file': 'form',
                    'analysis_storage_id': 'form',
                    'tool_cwl_files': 'form',
                    'metadata_model_file': 'form',
                    'links': 'form',
                    'version_comment': 'form',
                    'categories': 'form',
                    'html_documentation': 'form',
                    'proprietary': 'form',
                },
                'collection_format_map': {
                    'tool_cwl_files': 'csv',
                    'categories': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [
                    'multipart/form-data'
                ]
            },
            api_client=api_client
        )
        self.create_nextflow_pipeline_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectPipeline,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines:createNextflowPipeline',
                'operation_id': 'create_nextflow_pipeline',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'code',
                    'description',
                    'main_nextflow_file',
                    'parameters_xml_file',
                    'analysis_storage_id',
                    'pipeline_language_version_id',
                    'nextflow_config_file',
                    'other_nextflow_files',
                    'metadata_model_file',
                    'links',
                    'version_comment',
                    'categories',
                    'html_documentation',
                    'proprietary',
                ],
                'required': [
                    'project_id',
                    'code',
                    'description',
                    'main_nextflow_file',
                    'parameters_xml_file',
                    'analysis_storage_id',
                ],
                'nullable': [
                    'pipeline_language_version_id',
                    'metadata_model_file',
                    'links',
                    'version_comment',
                    'categories',
                    'html_documentation',
                    'proprietary',
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                    'description',
                    'categories',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 255,
                        'min_length': 1,
                        'regex': {
                            'pattern': r'^[a-zA-Z0-9 _-]*(\/[a-zA-Z0-9 _-]+)*$',  # noqa: E501
                        },
                    },
                    ('description',): {
                        'max_length': 4000,
                        'min_length': 1,
                    },
                    ('categories',): {

                        'max_items': 4000,
                        'min_items': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'code':
                        (str,),
                    'description':
                        (str,),
                    'main_nextflow_file':
                        (file_type,),
                    'parameters_xml_file':
                        (file_type,),
                    'analysis_storage_id':
                        (str,),
                    'pipeline_language_version_id':
                        (str, none_type,),
                    'nextflow_config_file':
                        (file_type,),
                    'other_nextflow_files':
                        ([file_type],),
                    'metadata_model_file':
                        (file_type, none_type,),
                    'links':
                        (Links,),
                    'version_comment':
                        (str, none_type,),
                    'categories':
                        ([str, none_type], none_type,),
                    'html_documentation':
                        (str, none_type,),
                    'proprietary':
                        (bool, none_type,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'code': 'code',
                    'description': 'description',
                    'main_nextflow_file': 'mainNextflowFile',
                    'parameters_xml_file': 'parametersXmlFile',
                    'analysis_storage_id': 'analysisStorageId',
                    'pipeline_language_version_id': 'pipelineLanguageVersionId',
                    'nextflow_config_file': 'nextflowConfigFile',
                    'other_nextflow_files': 'otherNextflowFiles',
                    'metadata_model_file': 'metadataModelFile',
                    'links': 'links',
                    'version_comment': 'versionComment',
                    'categories': 'categories',
                    'html_documentation': 'htmlDocumentation',
                    'proprietary': 'proprietary',
                },
                'location_map': {
                    'project_id': 'path',
                    'code': 'form',
                    'description': 'form',
                    'main_nextflow_file': 'form',
                    'parameters_xml_file': 'form',
                    'analysis_storage_id': 'form',
                    'pipeline_language_version_id': 'form',
                    'nextflow_config_file': 'form',
                    'other_nextflow_files': 'form',
                    'metadata_model_file': 'form',
                    'links': 'form',
                    'version_comment': 'form',
                    'categories': 'form',
                    'html_documentation': 'form',
                    'proprietary': 'form',
                },
                'collection_format_map': {
                    'other_nextflow_files': 'csv',
                    'categories': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [
                    'multipart/form-data'
                ]
            },
            api_client=api_client
        )
        self.create_project_pipeline_file_endpoint = _Endpoint(
            settings={
                'response_type': (PipelineFile,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines/{pipelineId}/files',
                'operation_id': 'create_project_pipeline_file',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'pipeline_id',
                    'content',
                ],
                'required': [
                    'project_id',
                    'pipeline_id',
                    'content',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'pipeline_id':
                        (str,),
                    'content':
                        (file_type,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'pipeline_id': 'pipelineId',
                    'content': 'content',
                },
                'location_map': {
                    'project_id': 'path',
                    'pipeline_id': 'path',
                    'content': 'form',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [
                    'multipart/form-data'
                ]
            },
            api_client=api_client
        )
        self.delete_project_pipeline_file_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines/{pipelineId}/files/{fileId}',
                'operation_id': 'delete_project_pipeline_file',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'pipeline_id',
                    'file_id',
                ],
                'required': [
                    'project_id',
                    'pipeline_id',
                    'file_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'pipeline_id':
                        (str,),
                    'file_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'pipeline_id': 'pipelineId',
                    'file_id': 'fileId',
                },
                'location_map': {
                    'project_id': 'path',
                    'pipeline_id': 'path',
                    'file_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.download_project_pipeline_file_content_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines/{pipelineId}/files/{fileId}/content',
                'operation_id': 'download_project_pipeline_file_content',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'pipeline_id',
                    'file_id',
                ],
                'required': [
                    'project_id',
                    'pipeline_id',
                    'file_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'pipeline_id':
                        (str,),
                    'file_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'pipeline_id': 'pipelineId',
                    'file_id': 'fileId',
                },
                'location_map': {
                    'project_id': 'path',
                    'pipeline_id': 'path',
                    'file_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/octet-stream'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_project_pipeline_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectPipeline,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines/{pipelineId}',
                'operation_id': 'get_project_pipeline',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'pipeline_id',
                ],
                'required': [
                    'project_id',
                    'pipeline_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'pipeline_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'pipeline_id': 'pipelineId',
                },
                'location_map': {
                    'project_id': 'path',
                    'pipeline_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_project_pipeline_configuration_parameters_endpoint = _Endpoint(
            settings={
                'response_type': (PipelineConfigurationParameterList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines/{pipelineId}/configurationParameters',
                'operation_id': 'get_project_pipeline_configuration_parameters',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'pipeline_id',
                ],
                'required': [
                    'project_id',
                    'pipeline_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'pipeline_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'pipeline_id': 'pipelineId',
                },
                'location_map': {
                    'project_id': 'path',
                    'pipeline_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_project_pipeline_files_endpoint = _Endpoint(
            settings={
                'response_type': (PipelineFileList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines/{pipelineId}/files',
                'operation_id': 'get_project_pipeline_files',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'pipeline_id',
                ],
                'required': [
                    'project_id',
                    'pipeline_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'pipeline_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'pipeline_id': 'pipelineId',
                },
                'location_map': {
                    'project_id': 'path',
                    'pipeline_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_project_pipeline_html_documentation_endpoint = _Endpoint(
            settings={
                'response_type': (PipelineHtmlDocumentation,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines/{pipelineId}/documentation/HTML',
                'operation_id': 'get_project_pipeline_html_documentation',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'pipeline_id',
                ],
                'required': [
                    'project_id',
                    'pipeline_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'pipeline_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'pipeline_id': 'pipelineId',
                },
                'location_map': {
                    'project_id': 'path',
                    'pipeline_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_project_pipeline_input_parameters_endpoint = _Endpoint(
            settings={
                'response_type': (InputParameterList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines/{pipelineId}/inputParameters',
                'operation_id': 'get_project_pipeline_input_parameters',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'pipeline_id',
                ],
                'required': [
                    'project_id',
                    'pipeline_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'pipeline_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'pipeline_id': 'pipelineId',
                },
                'location_map': {
                    'project_id': 'path',
                    'pipeline_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_project_pipeline_reference_sets_endpoint = _Endpoint(
            settings={
                'response_type': (ReferenceSetList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines/{pipelineId}/referenceSets',
                'operation_id': 'get_project_pipeline_reference_sets',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'pipeline_id',
                ],
                'required': [
                    'project_id',
                    'pipeline_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'pipeline_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'pipeline_id': 'pipelineId',
                },
                'location_map': {
                    'project_id': 'path',
                    'pipeline_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_project_pipelines_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectPipelineList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines',
                'operation_id': 'get_project_pipelines',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                ],
                'required': [
                    'project_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                },
                'location_map': {
                    'project_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.link_pipeline_to_project_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines/{pipelineId}',
                'operation_id': 'link_pipeline_to_project',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'pipeline_id',
                ],
                'required': [
                    'project_id',
                    'pipeline_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'pipeline_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'pipeline_id': 'pipelineId',
                },
                'location_map': {
                    'project_id': 'path',
                    'pipeline_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.release_project_pipeline_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines/{pipelineId}:release',
                'operation_id': 'release_project_pipeline',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'pipeline_id',
                ],
                'required': [
                    'project_id',
                    'pipeline_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'pipeline_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'pipeline_id': 'pipelineId',
                },
                'location_map': {
                    'project_id': 'path',
                    'pipeline_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.unlink_pipeline_from_project_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines/{pipelineId}',
                'operation_id': 'unlink_pipeline_from_project',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'pipeline_id',
                ],
                'required': [
                    'project_id',
                    'pipeline_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'pipeline_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'pipeline_id': 'pipelineId',
                },
                'location_map': {
                    'project_id': 'path',
                    'pipeline_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_project_pipeline_file_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/pipelines/{pipelineId}/files/{fileId}/content',
                'operation_id': 'update_project_pipeline_file',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'pipeline_id',
                    'file_id',
                    'content',
                ],
                'required': [
                    'project_id',
                    'pipeline_id',
                    'file_id',
                    'content',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'pipeline_id':
                        (str,),
                    'file_id':
                        (str,),
                    'content':
                        (file_type,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'pipeline_id': 'pipelineId',
                    'file_id': 'fileId',
                    'content': 'content',
                },
                'location_map': {
                    'project_id': 'path',
                    'pipeline_id': 'path',
                    'file_id': 'path',
                    'content': 'form',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [
                    'multipart/form-data'
                ]
            },
            api_client=api_client
        )

    def create_cwl_pipeline(
        self,
        project_id,
        code,
        description,
        workflow_cwl_file,
        parameters_xml_file,
        analysis_storage_id,
        **kwargs
    ):
        """Create a CWL pipeline within a project.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_cwl_pipeline(project_id, code, description, workflow_cwl_file, parameters_xml_file, analysis_storage_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            code (str): The code of the CWL pipeline
            description (str): The description of the CWL pipeline
            workflow_cwl_file (file_type): The CWL workflow file.
            parameters_xml_file (file_type):
            analysis_storage_id (str): The id of the storage to use for the pipeline.

        Keyword Args:
            tool_cwl_files ([file_type]): [optional]
            metadata_model_file (file_type, none_type): The metadata model json file(contents can be retrieved from the controlplane).. [optional]
            links (Links): [optional]
            version_comment (str, none_type): [optional]
            categories ([str, none_type], none_type): [optional]
            html_documentation (str, none_type): [optional]
            proprietary (bool, none_type): A boolean which indicates if the code of this pipeline is proprietary. [optional] if omitted the server will use the default value of False
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ProjectPipeline
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['code'] = \
            code
        kwargs['description'] = \
            description
        kwargs['workflow_cwl_file'] = \
            workflow_cwl_file
        kwargs['parameters_xml_file'] = \
            parameters_xml_file
        kwargs['analysis_storage_id'] = \
            analysis_storage_id
        return self.create_cwl_pipeline_endpoint.call_with_http_info(**kwargs)

    def create_nextflow_pipeline(
        self,
        project_id,
        code,
        description,
        main_nextflow_file,
        parameters_xml_file,
        analysis_storage_id,
        **kwargs
    ):
        """Create a Nextflow pipeline within a project.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_nextflow_pipeline(project_id, code, description, main_nextflow_file, parameters_xml_file, analysis_storage_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            code (str): The code of the pipeline
            description (str): The description of the pipeline
            main_nextflow_file (file_type): The main Nextflow file.
            parameters_xml_file (file_type):
            analysis_storage_id (str): The id of the storage to use for the pipeline.

        Keyword Args:
            pipeline_language_version_id (str, none_type): The id of the Nextflow version to use for the pipeline.. [optional]
            nextflow_config_file (file_type): The Nextflow config file.. [optional]
            other_nextflow_files ([file_type]): [optional]
            metadata_model_file (file_type, none_type): The metadata model json file(contents can be retrieved from the controlplane).. [optional]
            links (Links): [optional]
            version_comment (str, none_type): [optional]
            categories ([str, none_type], none_type): [optional]
            html_documentation (str, none_type): [optional]
            proprietary (bool, none_type): A boolean which indicates if the code of this pipeline is proprietary. [optional] if omitted the server will use the default value of False
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ProjectPipeline
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['code'] = \
            code
        kwargs['description'] = \
            description
        kwargs['main_nextflow_file'] = \
            main_nextflow_file
        kwargs['parameters_xml_file'] = \
            parameters_xml_file
        kwargs['analysis_storage_id'] = \
            analysis_storage_id
        return self.create_nextflow_pipeline_endpoint.call_with_http_info(**kwargs)

    def create_project_pipeline_file(
        self,
        project_id,
        pipeline_id,
        content,
        **kwargs
    ):
        """Create a file for a pipeline.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_project_pipeline_file(project_id, pipeline_id, content, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            pipeline_id (str): The ID of the project pipeline to create a file for
            content (file_type):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            PipelineFile
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['pipeline_id'] = \
            pipeline_id
        kwargs['content'] = \
            content
        return self.create_project_pipeline_file_endpoint.call_with_http_info(**kwargs)

    def delete_project_pipeline_file(
        self,
        project_id,
        pipeline_id,
        file_id,
        **kwargs
    ):
        """Delete a file for a pipeline.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_project_pipeline_file(project_id, pipeline_id, file_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            pipeline_id (str): The ID of the project pipeline to delete a file for
            file_id (str): The ID of the pipeline file

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['pipeline_id'] = \
            pipeline_id
        kwargs['file_id'] = \
            file_id
        return self.delete_project_pipeline_file_endpoint.call_with_http_info(**kwargs)

    def download_project_pipeline_file_content(
        self,
        project_id,
        pipeline_id,
        file_id,
        **kwargs
    ):
        """Download the contents of a pipeline file.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.download_project_pipeline_file_content(project_id, pipeline_id, file_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            pipeline_id (str): The ID of the project pipeline to retrieve files for
            file_id (str): The ID of the pipeline file

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['pipeline_id'] = \
            pipeline_id
        kwargs['file_id'] = \
            file_id
        return self.download_project_pipeline_file_content_endpoint.call_with_http_info(**kwargs)

    def get_project_pipeline(
        self,
        project_id,
        pipeline_id,
        **kwargs
    ):
        """Retrieve a project pipeline.  # noqa: E501

        Retrieves a project pipeline. This can be a pipeline from a linked bundle or an entitled, unlinked bundle.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_project_pipeline(project_id, pipeline_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            pipeline_id (str): The ID of the project pipeline to retrieve

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ProjectPipeline
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['pipeline_id'] = \
            pipeline_id
        return self.get_project_pipeline_endpoint.call_with_http_info(**kwargs)

    def get_project_pipeline_configuration_parameters(
        self,
        project_id,
        pipeline_id,
        **kwargs
    ):
        """Retrieve configuration parameters for a project pipeline.  # noqa: E501

        The pipeline can originate from a linked bundle.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_project_pipeline_configuration_parameters(project_id, pipeline_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            pipeline_id (str): The ID of the project pipeline to retrieve input parameters for

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            PipelineConfigurationParameterList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['pipeline_id'] = \
            pipeline_id
        return self.get_project_pipeline_configuration_parameters_endpoint.call_with_http_info(**kwargs)

    def get_project_pipeline_files(
        self,
        project_id,
        pipeline_id,
        **kwargs
    ):
        """Retrieve files for a project pipeline.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_project_pipeline_files(project_id, pipeline_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            pipeline_id (str): The ID of the project pipeline to retrieve files for

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            PipelineFileList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['pipeline_id'] = \
            pipeline_id
        return self.get_project_pipeline_files_endpoint.call_with_http_info(**kwargs)

    def get_project_pipeline_html_documentation(
        self,
        project_id,
        pipeline_id,
        **kwargs
    ):
        """Retrieve HTML documentation for a project pipeline.  # noqa: E501

        Retrieve HTML documentation for a project pipeline. This can be a pipeline from a linked bundle.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_project_pipeline_html_documentation(project_id, pipeline_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            pipeline_id (str): The ID of the project pipeline to retrieve HTML documentation from

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            PipelineHtmlDocumentation
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['pipeline_id'] = \
            pipeline_id
        return self.get_project_pipeline_html_documentation_endpoint.call_with_http_info(**kwargs)

    def get_project_pipeline_input_parameters(
        self,
        project_id,
        pipeline_id,
        **kwargs
    ):
        """Retrieve input parameters for a project pipeline.  # noqa: E501

        The pipeline can originate from a linked bundle.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_project_pipeline_input_parameters(project_id, pipeline_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            pipeline_id (str): The ID of the project pipeline to retrieve input parameters for

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            InputParameterList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['pipeline_id'] = \
            pipeline_id
        return self.get_project_pipeline_input_parameters_endpoint.call_with_http_info(**kwargs)

    def get_project_pipeline_reference_sets(
        self,
        project_id,
        pipeline_id,
        **kwargs
    ):
        """Retrieve the reference sets of a project pipeline.  # noqa: E501

        Retrieve the reference sets of a project pipeline. This can be a pipeline from a linked bundle.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_project_pipeline_reference_sets(project_id, pipeline_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            pipeline_id (str): The ID of the pipeline to retrieve reference sets for

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ReferenceSetList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['pipeline_id'] = \
            pipeline_id
        return self.get_project_pipeline_reference_sets_endpoint.call_with_http_info(**kwargs)

    def get_project_pipelines(
        self,
        project_id,
        **kwargs
    ):
        """Retrieve a list of project pipelines.  # noqa: E501

        Lists all pipelines that are available to the project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_project_pipelines(project_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str): The ID of the project to retrieve pipelines for

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ProjectPipelineList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        return self.get_project_pipelines_endpoint.call_with_http_info(**kwargs)

    def link_pipeline_to_project(
        self,
        project_id,
        pipeline_id,
        **kwargs
    ):
        """Link a pipeline to a project.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.link_pipeline_to_project(project_id, pipeline_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            pipeline_id (str): The ID of the pipeline

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['pipeline_id'] = \
            pipeline_id
        return self.link_pipeline_to_project_endpoint.call_with_http_info(**kwargs)

    def release_project_pipeline(
        self,
        project_id,
        pipeline_id,
        **kwargs
    ):
        """Release a pipeline.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.release_project_pipeline(project_id, pipeline_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            pipeline_id (str): The ID of the pipeline

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['pipeline_id'] = \
            pipeline_id
        return self.release_project_pipeline_endpoint.call_with_http_info(**kwargs)

    def unlink_pipeline_from_project(
        self,
        project_id,
        pipeline_id,
        **kwargs
    ):
        """Unlink a pipeline from a project.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.unlink_pipeline_from_project(project_id, pipeline_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            pipeline_id (str): The ID of the pipeline

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['pipeline_id'] = \
            pipeline_id
        return self.unlink_pipeline_from_project_endpoint.call_with_http_info(**kwargs)

    def update_project_pipeline_file(
        self,
        project_id,
        pipeline_id,
        file_id,
        content,
        **kwargs
    ):
        """Update the contents of a file for a pipeline.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_project_pipeline_file(project_id, pipeline_id, file_id, content, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            pipeline_id (str): The ID of the project pipeline to update a file for
            file_id (str): The ID of the pipeline file
            content (file_type):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['pipeline_id'] = \
            pipeline_id
        kwargs['file_id'] = \
            file_id
        kwargs['content'] = \
            content
        return self.update_project_pipeline_file_endpoint.call_with_http_info(**kwargs)




# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from libica.openapi.v2.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from libica.openapi.v2.model.aws_details import AWSDetails
from libica.openapi.v2.model.activation_code_detail import ActivationCodeDetail
from libica.openapi.v2.model.activation_code_detail_list import ActivationCodeDetailList
from libica.openapi.v2.model.activation_code_detail_usage import ActivationCodeDetailUsage
from libica.openapi.v2.model.analysis import Analysis
from libica.openapi.v2.model.analysis_base_space_data_details import AnalysisBaseSpaceDataDetails
from libica.openapi.v2.model.analysis_creation_batch import AnalysisCreationBatch
from libica.openapi.v2.model.analysis_creation_batch_item import AnalysisCreationBatchItem
from libica.openapi.v2.model.analysis_creation_batch_item_paged_list import AnalysisCreationBatchItemPagedList
from libica.openapi.v2.model.analysis_creation_batch_item_processing import AnalysisCreationBatchItemProcessing
from libica.openapi.v2.model.analysis_creation_batch_item_request import AnalysisCreationBatchItemRequest
from libica.openapi.v2.model.analysis_data import AnalysisData
from libica.openapi.v2.model.analysis_data_input import AnalysisDataInput
from libica.openapi.v2.model.analysis_external_data import AnalysisExternalData
from libica.openapi.v2.model.analysis_input import AnalysisInput
from libica.openapi.v2.model.analysis_input_data_mount import AnalysisInputDataMount
from libica.openapi.v2.model.analysis_input_external_data import AnalysisInputExternalData
from libica.openapi.v2.model.analysis_input_list import AnalysisInputList
from libica.openapi.v2.model.analysis_output import AnalysisOutput
from libica.openapi.v2.model.analysis_output_list import AnalysisOutputList
from libica.openapi.v2.model.analysis_output_mapping import AnalysisOutputMapping
from libica.openapi.v2.model.analysis_paged_list import AnalysisPagedList
from libica.openapi.v2.model.analysis_parameter_input import AnalysisParameterInput
from libica.openapi.v2.model.analysis_raw_output import AnalysisRawOutput
from libica.openapi.v2.model.analysis_reference_data_parameter import AnalysisReferenceDataParameter
from libica.openapi.v2.model.analysis_s3_data_details import AnalysisS3DataDetails
from libica.openapi.v2.model.analysis_step import AnalysisStep
from libica.openapi.v2.model.analysis_step_list import AnalysisStepList
from libica.openapi.v2.model.analysis_step_logs import AnalysisStepLogs
from libica.openapi.v2.model.analysis_storage import AnalysisStorage
from libica.openapi.v2.model.analysis_storage_list import AnalysisStorageList
from libica.openapi.v2.model.analysis_tag import AnalysisTag
from libica.openapi.v2.model.application import Application
from libica.openapi.v2.model.aws_credentials import AwsCredentials
from libica.openapi.v2.model.aws_temp_credentials import AwsTempCredentials
from libica.openapi.v2.model.base_connection import BaseConnection
from libica.openapi.v2.model.base_job import BaseJob
from libica.openapi.v2.model.base_job_list import BaseJobList
from libica.openapi.v2.model.bundle import Bundle
from libica.openapi.v2.model.bundle_data import BundleData
from libica.openapi.v2.model.bundle_data_linking_batch import BundleDataLinkingBatch
from libica.openapi.v2.model.bundle_data_linking_batch_item import BundleDataLinkingBatchItem
from libica.openapi.v2.model.bundle_data_linking_batch_item_paged_list import BundleDataLinkingBatchItemPagedList
from libica.openapi.v2.model.bundle_data_linking_batch_item_processing import BundleDataLinkingBatchItemProcessing
from libica.openapi.v2.model.bundle_data_linking_batch_item_request import BundleDataLinkingBatchItemRequest
from libica.openapi.v2.model.bundle_data_paged_list import BundleDataPagedList
from libica.openapi.v2.model.bundle_data_unlinking_batch import BundleDataUnlinkingBatch
from libica.openapi.v2.model.bundle_data_unlinking_batch_item import BundleDataUnlinkingBatchItem
from libica.openapi.v2.model.bundle_data_unlinking_batch_item_paged_list import BundleDataUnlinkingBatchItemPagedList
from libica.openapi.v2.model.bundle_data_unlinking_batch_item_processing import BundleDataUnlinkingBatchItemProcessing
from libica.openapi.v2.model.bundle_data_unlinking_batch_item_request import BundleDataUnlinkingBatchItemRequest
from libica.openapi.v2.model.bundle_list import BundleList
from libica.openapi.v2.model.bundle_paged_list import BundlePagedList
from libica.openapi.v2.model.bundle_pipeline import BundlePipeline
from libica.openapi.v2.model.bundle_pipeline_list import BundlePipelineList
from libica.openapi.v2.model.bundle_sample import BundleSample
from libica.openapi.v2.model.bundle_sample_paged_list import BundleSamplePagedList
from libica.openapi.v2.model.bundle_tool import BundleTool
from libica.openapi.v2.model.bundle_tools_list import BundleToolsList
from libica.openapi.v2.model.cwl_tool_definition import CWLToolDefinition
from libica.openapi.v2.model.change_project_owner import ChangeProjectOwner
from libica.openapi.v2.model.complete_folder_upload_session import CompleteFolderUploadSession
from libica.openapi.v2.model.connector import Connector
from libica.openapi.v2.model.connector_list import ConnectorList
from libica.openapi.v2.model.country import Country
from libica.openapi.v2.model.create_analysis_creation_batch import CreateAnalysisCreationBatch
from libica.openapi.v2.model.create_bundle import CreateBundle
from libica.openapi.v2.model.create_bundle_data_linking_batch import CreateBundleDataLinkingBatch
from libica.openapi.v2.model.create_bundle_data_linking_batch_item import CreateBundleDataLinkingBatchItem
from libica.openapi.v2.model.create_bundle_data_unlinking_batch import CreateBundleDataUnlinkingBatch
from libica.openapi.v2.model.create_bundle_data_unlinking_batch_item import CreateBundleDataUnlinkingBatchItem
from libica.openapi.v2.model.create_connector import CreateConnector
from libica.openapi.v2.model.create_custom_event import CreateCustomEvent
from libica.openapi.v2.model.create_custom_notification_subscription import CreateCustomNotificationSubscription
from libica.openapi.v2.model.create_cwl_analysis import CreateCwlAnalysis
from libica.openapi.v2.model.create_data import CreateData
from libica.openapi.v2.model.create_download_rule import CreateDownloadRule
from libica.openapi.v2.model.create_nextflow_analysis import CreateNextflowAnalysis
from libica.openapi.v2.model.create_notification_channel import CreateNotificationChannel
from libica.openapi.v2.model.create_notification_subscription import CreateNotificationSubscription
from libica.openapi.v2.model.create_project import CreateProject
from libica.openapi.v2.model.create_project_data_copy_batch import CreateProjectDataCopyBatch
from libica.openapi.v2.model.create_project_data_copy_batch_item import CreateProjectDataCopyBatchItem
from libica.openapi.v2.model.create_project_data_linking_batch import CreateProjectDataLinkingBatch
from libica.openapi.v2.model.create_project_data_linking_batch_item import CreateProjectDataLinkingBatchItem
from libica.openapi.v2.model.create_project_data_unlinking_batch import CreateProjectDataUnlinkingBatch
from libica.openapi.v2.model.create_project_data_unlinking_batch_item import CreateProjectDataUnlinkingBatchItem
from libica.openapi.v2.model.create_project_data_update_batch import CreateProjectDataUpdateBatch
from libica.openapi.v2.model.create_project_permission import CreateProjectPermission
from libica.openapi.v2.model.create_project_permission_v4 import CreateProjectPermissionV4
from libica.openapi.v2.model.create_sample import CreateSample
from libica.openapi.v2.model.create_sample_creation_batch import CreateSampleCreationBatch
from libica.openapi.v2.model.create_sample_creation_batch_data_item import CreateSampleCreationBatchDataItem
from libica.openapi.v2.model.create_sample_creation_batch_sample_item import CreateSampleCreationBatchSampleItem
from libica.openapi.v2.model.create_storage_configuration import CreateStorageConfiguration
from libica.openapi.v2.model.create_storage_credential import CreateStorageCredential
from libica.openapi.v2.model.create_temporary_credentials import CreateTemporaryCredentials
from libica.openapi.v2.model.create_terms_of_use import CreateTermsOfUse
from libica.openapi.v2.model.create_upload_rule import CreateUploadRule
from libica.openapi.v2.model.custom_notification_subscription import CustomNotificationSubscription
from libica.openapi.v2.model.custom_notification_subscription_list import CustomNotificationSubscriptionList
from libica.openapi.v2.model.cwl_analysis_input import CwlAnalysisInput
from libica.openapi.v2.model.cwl_analysis_input_json import CwlAnalysisInputJson
from libica.openapi.v2.model.cwl_analysis_json_input import CwlAnalysisJsonInput
from libica.openapi.v2.model.cwl_analysis_output_json import CwlAnalysisOutputJson
from libica.openapi.v2.model.cwl_analysis_structured_input import CwlAnalysisStructuredInput
from libica.openapi.v2.model.cwl_tool_definition_list import CwlToolDefinitionList
from libica.openapi.v2.model.data import Data
from libica.openapi.v2.model.data_details import DataDetails
from libica.openapi.v2.model.data_format import DataFormat
from libica.openapi.v2.model.data_format_paged_list import DataFormatPagedList
from libica.openapi.v2.model.data_id_or_path_list import DataIdOrPathList
from libica.openapi.v2.model.data_list import DataList
from libica.openapi.v2.model.data_paged_list import DataPagedList
from libica.openapi.v2.model.data_tag import DataTag
from libica.openapi.v2.model.data_transfer import DataTransfer
from libica.openapi.v2.model.data_transfer_paged_list import DataTransferPagedList
from libica.openapi.v2.model.data_update_group import DataUpdateGroup
from libica.openapi.v2.model.data_url_with_path import DataUrlWithPath
from libica.openapi.v2.model.data_url_with_path_list import DataUrlWithPathList
from libica.openapi.v2.model.download import Download
from libica.openapi.v2.model.download_rule import DownloadRule
from libica.openapi.v2.model.download_rule_list import DownloadRuleList
from libica.openapi.v2.model.event_code import EventCode
from libica.openapi.v2.model.event_code_list import EventCodeList
from libica.openapi.v2.model.event_log import EventLog
from libica.openapi.v2.model.event_log_list import EventLogList
from libica.openapi.v2.model.execution_configuration import ExecutionConfiguration
from libica.openapi.v2.model.execution_configuration_list import ExecutionConfigurationList
from libica.openapi.v2.model.field import Field
from libica.openapi.v2.model.field_id import FieldId
from libica.openapi.v2.model.field_list import FieldList
from libica.openapi.v2.model.find_project_samples import FindProjectSamples
from libica.openapi.v2.model.find_sample_boolean_condition import FindSampleBooleanCondition
from libica.openapi.v2.model.find_sample_condition import FindSampleCondition
from libica.openapi.v2.model.find_sample_date_condition import FindSampleDateCondition
from libica.openapi.v2.model.find_sample_number_condition import FindSampleNumberCondition
from libica.openapi.v2.model.folder_upload_session import FolderUploadSession
from libica.openapi.v2.model.inline_view import InlineView
from libica.openapi.v2.model.input_parameter import InputParameter
from libica.openapi.v2.model.input_parameter_list import InputParameterList
from libica.openapi.v2.model.input_part import InputPart
from libica.openapi.v2.model.input_part_media_type import InputPartMediaType
from libica.openapi.v2.model.integer_settings import IntegerSettings
from libica.openapi.v2.model.job import Job
from libica.openapi.v2.model.job_paged_list import JobPagedList
from libica.openapi.v2.model.link import Link
from libica.openapi.v2.model.links import Links
from libica.openapi.v2.model.load_data_in_base_request import LoadDataInBaseRequest
from libica.openapi.v2.model.metadata_field import MetadataField
from libica.openapi.v2.model.metadata_model import MetadataModel
from libica.openapi.v2.model.metadata_model_list import MetadataModelList
from libica.openapi.v2.model.model import Model
from libica.openapi.v2.model.multipart_form_data_input import MultipartFormDataInput
from libica.openapi.v2.model.nextflow_analysis_input import NextflowAnalysisInput
from libica.openapi.v2.model.notification_channel import NotificationChannel
from libica.openapi.v2.model.notification_channel_list import NotificationChannelList
from libica.openapi.v2.model.notification_subscription import NotificationSubscription
from libica.openapi.v2.model.notification_subscription_list import NotificationSubscriptionList
from libica.openapi.v2.model.option_settings import OptionSettings
from libica.openapi.v2.model.optional_sample_tags import OptionalSampleTags
from libica.openapi.v2.model.pipeline import Pipeline
from libica.openapi.v2.model.pipeline_bundle import PipelineBundle
from libica.openapi.v2.model.pipeline_configuration_parameter import PipelineConfigurationParameter
from libica.openapi.v2.model.pipeline_configuration_parameter_list import PipelineConfigurationParameterList
from libica.openapi.v2.model.pipeline_file import PipelineFile
from libica.openapi.v2.model.pipeline_file_list import PipelineFileList
from libica.openapi.v2.model.pipeline_html_documentation import PipelineHtmlDocumentation
from libica.openapi.v2.model.pipeline_language_version import PipelineLanguageVersion
from libica.openapi.v2.model.pipeline_language_version_list import PipelineLanguageVersionList
from libica.openapi.v2.model.pipeline_list import PipelineList
from libica.openapi.v2.model.pipeline_tag import PipelineTag
from libica.openapi.v2.model.problem import Problem
from libica.openapi.v2.model.project import Project
from libica.openapi.v2.model.project_base_table import ProjectBaseTable
from libica.openapi.v2.model.project_base_table_list import ProjectBaseTableList
from libica.openapi.v2.model.project_bundle import ProjectBundle
from libica.openapi.v2.model.project_bundle_list import ProjectBundleList
from libica.openapi.v2.model.project_data import ProjectData
from libica.openapi.v2.model.project_data_copy_batch import ProjectDataCopyBatch
from libica.openapi.v2.model.project_data_copy_batch_item import ProjectDataCopyBatchItem
from libica.openapi.v2.model.project_data_copy_batch_item_paged_list import ProjectDataCopyBatchItemPagedList
from libica.openapi.v2.model.project_data_copy_batch_item_processing import ProjectDataCopyBatchItemProcessing
from libica.openapi.v2.model.project_data_copy_batch_item_request import ProjectDataCopyBatchItemRequest
from libica.openapi.v2.model.project_data_linking_batch import ProjectDataLinkingBatch
from libica.openapi.v2.model.project_data_linking_batch_item import ProjectDataLinkingBatchItem
from libica.openapi.v2.model.project_data_linking_batch_item_paged_list import ProjectDataLinkingBatchItemPagedList
from libica.openapi.v2.model.project_data_linking_batch_item_paged_list_v4 import ProjectDataLinkingBatchItemPagedListV4
from libica.openapi.v2.model.project_data_linking_batch_item_processing import ProjectDataLinkingBatchItemProcessing
from libica.openapi.v2.model.project_data_linking_batch_item_processing_v4 import ProjectDataLinkingBatchItemProcessingV4
from libica.openapi.v2.model.project_data_linking_batch_item_request import ProjectDataLinkingBatchItemRequest
from libica.openapi.v2.model.project_data_linking_batch_item_v4 import ProjectDataLinkingBatchItemV4
from libica.openapi.v2.model.project_data_paged_list import ProjectDataPagedList
from libica.openapi.v2.model.project_data_unlinking_batch import ProjectDataUnlinkingBatch
from libica.openapi.v2.model.project_data_unlinking_batch_item import ProjectDataUnlinkingBatchItem
from libica.openapi.v2.model.project_data_unlinking_batch_item_paged_list import ProjectDataUnlinkingBatchItemPagedList
from libica.openapi.v2.model.project_data_unlinking_batch_item_processing import ProjectDataUnlinkingBatchItemProcessing
from libica.openapi.v2.model.project_data_unlinking_batch_item_request import ProjectDataUnlinkingBatchItemRequest
from libica.openapi.v2.model.project_data_update_batch import ProjectDataUpdateBatch
from libica.openapi.v2.model.project_data_update_batch_item import ProjectDataUpdateBatchItem
from libica.openapi.v2.model.project_data_update_batch_item_paged_list import ProjectDataUpdateBatchItemPagedList
from libica.openapi.v2.model.project_data_update_batch_item_processing import ProjectDataUpdateBatchItemProcessing
from libica.openapi.v2.model.project_data_update_batch_item_request import ProjectDataUpdateBatchItemRequest
from libica.openapi.v2.model.project_list import ProjectList
from libica.openapi.v2.model.project_paged_list import ProjectPagedList
from libica.openapi.v2.model.project_permission import ProjectPermission
from libica.openapi.v2.model.project_permission_list import ProjectPermissionList
from libica.openapi.v2.model.project_permission_list_v4 import ProjectPermissionListV4
from libica.openapi.v2.model.project_permission_v4 import ProjectPermissionV4
from libica.openapi.v2.model.project_pipeline import ProjectPipeline
from libica.openapi.v2.model.project_pipeline_list import ProjectPipelineList
from libica.openapi.v2.model.project_sample import ProjectSample
from libica.openapi.v2.model.project_sample_paged_list import ProjectSamplePagedList
from libica.openapi.v2.model.project_tag import ProjectTag
from libica.openapi.v2.model.rclone_temp_credentials import RcloneTempCredentials
from libica.openapi.v2.model.reference_data import ReferenceData
from libica.openapi.v2.model.reference_data_list import ReferenceDataList
from libica.openapi.v2.model.reference_data_type import ReferenceDataType
from libica.openapi.v2.model.reference_data_type_list import ReferenceDataTypeList
from libica.openapi.v2.model.reference_set import ReferenceSet
from libica.openapi.v2.model.reference_set_list import ReferenceSetList
from libica.openapi.v2.model.region import Region
from libica.openapi.v2.model.region_list import RegionList
from libica.openapi.v2.model.sample import Sample
from libica.openapi.v2.model.sample_creation_batch import SampleCreationBatch
from libica.openapi.v2.model.sample_creation_batch_item_paged_list import SampleCreationBatchItemPagedList
from libica.openapi.v2.model.sample_creation_batch_item_processing import SampleCreationBatchItemProcessing
from libica.openapi.v2.model.sample_creation_batch_item_request import SampleCreationBatchItemRequest
from libica.openapi.v2.model.sample_creation_batch_sample_item import SampleCreationBatchSampleItem
from libica.openapi.v2.model.sample_history import SampleHistory
from libica.openapi.v2.model.sample_history_list import SampleHistoryList
from libica.openapi.v2.model.sample_paged_list import SamplePagedList
from libica.openapi.v2.model.sample_tag import SampleTag
from libica.openapi.v2.model.schedule_download import ScheduleDownload
from libica.openapi.v2.model.search_matching_activation_codes_for_cwl_analysis import SearchMatchingActivationCodesForCwlAnalysis
from libica.openapi.v2.model.search_matching_activation_codes_for_nextflow_analysis import SearchMatchingActivationCodesForNextflowAnalysis
from libica.openapi.v2.model.sequencing_run import SequencingRun
from libica.openapi.v2.model.settings import Settings
from libica.openapi.v2.model.species import Species
from libica.openapi.v2.model.species_list import SpeciesList
from libica.openapi.v2.model.storage_bundle import StorageBundle
from libica.openapi.v2.model.storage_bundle_list import StorageBundleList
from libica.openapi.v2.model.storage_configuration import StorageConfiguration
from libica.openapi.v2.model.storage_configuration_details import StorageConfigurationDetails
from libica.openapi.v2.model.storage_configuration_with_details import StorageConfigurationWithDetails
from libica.openapi.v2.model.storage_configuration_with_details_list import StorageConfigurationWithDetailsList
from libica.openapi.v2.model.storage_credential import StorageCredential
from libica.openapi.v2.model.storage_credential_list import StorageCredentialList
from libica.openapi.v2.model.string_settings import StringSettings
from libica.openapi.v2.model.system_info import SystemInfo
from libica.openapi.v2.model.tag_update import TagUpdate
from libica.openapi.v2.model.temp_credentials import TempCredentials
from libica.openapi.v2.model.terms_of_use import TermsOfUse
from libica.openapi.v2.model.terms_of_use_acceptance import TermsOfUseAcceptance
from libica.openapi.v2.model.token import Token
from libica.openapi.v2.model.update_metadata import UpdateMetadata
from libica.openapi.v2.model.update_metadata_field_group import UpdateMetadataFieldGroup
from libica.openapi.v2.model.update_single_metadata_field import UpdateSingleMetadataField
from libica.openapi.v2.model.update_storage_credential_secrets import UpdateStorageCredentialSecrets
from libica.openapi.v2.model.upload import Upload
from libica.openapi.v2.model.upload_rule import UploadRule
from libica.openapi.v2.model.upload_rule_list import UploadRuleList
from libica.openapi.v2.model.user import User
from libica.openapi.v2.model.user_list import UserList
from libica.openapi.v2.model.workflow import Workflow
from libica.openapi.v2.model.workflow_session import WorkflowSession
from libica.openapi.v2.model.workflow_session_configuration import WorkflowSessionConfiguration
from libica.openapi.v2.model.workflow_session_configuration_list import WorkflowSessionConfigurationList
from libica.openapi.v2.model.workflow_session_data import WorkflowSessionData
from libica.openapi.v2.model.workflow_session_external_data import WorkflowSessionExternalData
from libica.openapi.v2.model.workflow_session_input import WorkflowSessionInput
from libica.openapi.v2.model.workflow_session_input_list import WorkflowSessionInputList
from libica.openapi.v2.model.workflow_session_paged_list import WorkflowSessionPagedList
from libica.openapi.v2.model.workflow_session_tag import WorkflowSessionTag
from libica.openapi.v2.model.workgroup import Workgroup
from libica.openapi.v2.model.workgroup_list import WorkgroupList



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class VolumeConfigurationListResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'items': 'list[VolumeConfigurationResponse]',
        'item_count': 'int',
        'first_page_token': 'str',
        'next_page_token': 'str',
        'prev_page_token': 'str',
        'last_page_token': 'str',
        'total_item_count': 'int',
        'total_page_count': 'int'
    }

    attribute_map = {
        'items': 'items',
        'item_count': 'itemCount',
        'first_page_token': 'firstPageToken',
        'next_page_token': 'nextPageToken',
        'prev_page_token': 'prevPageToken',
        'last_page_token': 'lastPageToken',
        'total_item_count': 'totalItemCount',
        'total_page_count': 'totalPageCount'
    }

    def __init__(self, items=None, item_count=None, first_page_token=None, next_page_token=None, prev_page_token=None, last_page_token=None, total_item_count=None, total_page_count=None, local_vars_configuration=None):  # noqa: E501
        """VolumeConfigurationListResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._items = None
        self._item_count = None
        self._first_page_token = None
        self._next_page_token = None
        self._prev_page_token = None
        self._last_page_token = None
        self._total_item_count = None
        self._total_page_count = None
        self.discriminator = None

        if items is not None:
            self.items = items
        if item_count is not None:
            self.item_count = item_count
        if first_page_token is not None:
            self.first_page_token = first_page_token
        if next_page_token is not None:
            self.next_page_token = next_page_token
        if prev_page_token is not None:
            self.prev_page_token = prev_page_token
        if last_page_token is not None:
            self.last_page_token = last_page_token
        if total_item_count is not None:
            self.total_item_count = total_item_count
        if total_page_count is not None:
            self.total_page_count = total_page_count

    @property
    def items(self):
        """Gets the items of this VolumeConfigurationListResponse.  # noqa: E501

        Items in paged list  # noqa: E501

        :return: The items of this VolumeConfigurationListResponse.  # noqa: E501
        :rtype: list[VolumeConfigurationResponse]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this VolumeConfigurationListResponse.

        Items in paged list  # noqa: E501

        :param items: The items of this VolumeConfigurationListResponse.  # noqa: E501
        :type: list[VolumeConfigurationResponse]
        """

        self._items = items

    @property
    def item_count(self):
        """Gets the item_count of this VolumeConfigurationListResponse.  # noqa: E501

        Number of items included in the page  # noqa: E501

        :return: The item_count of this VolumeConfigurationListResponse.  # noqa: E501
        :rtype: int
        """
        return self._item_count

    @item_count.setter
    def item_count(self, item_count):
        """Sets the item_count of this VolumeConfigurationListResponse.

        Number of items included in the page  # noqa: E501

        :param item_count: The item_count of this VolumeConfigurationListResponse.  # noqa: E501
        :type: int
        """

        self._item_count = item_count

    @property
    def first_page_token(self):
        """Gets the first_page_token of this VolumeConfigurationListResponse.  # noqa: E501

        PageToken for first paged list  # noqa: E501

        :return: The first_page_token of this VolumeConfigurationListResponse.  # noqa: E501
        :rtype: str
        """
        return self._first_page_token

    @first_page_token.setter
    def first_page_token(self, first_page_token):
        """Sets the first_page_token of this VolumeConfigurationListResponse.

        PageToken for first paged list  # noqa: E501

        :param first_page_token: The first_page_token of this VolumeConfigurationListResponse.  # noqa: E501
        :type: str
        """

        self._first_page_token = first_page_token

    @property
    def next_page_token(self):
        """Gets the next_page_token of this VolumeConfigurationListResponse.  # noqa: E501

        PageToken for the next paged list  # noqa: E501

        :return: The next_page_token of this VolumeConfigurationListResponse.  # noqa: E501
        :rtype: str
        """
        return self._next_page_token

    @next_page_token.setter
    def next_page_token(self, next_page_token):
        """Sets the next_page_token of this VolumeConfigurationListResponse.

        PageToken for the next paged list  # noqa: E501

        :param next_page_token: The next_page_token of this VolumeConfigurationListResponse.  # noqa: E501
        :type: str
        """

        self._next_page_token = next_page_token

    @property
    def prev_page_token(self):
        """Gets the prev_page_token of this VolumeConfigurationListResponse.  # noqa: E501

        PageToken for the previous paged list  # noqa: E501

        :return: The prev_page_token of this VolumeConfigurationListResponse.  # noqa: E501
        :rtype: str
        """
        return self._prev_page_token

    @prev_page_token.setter
    def prev_page_token(self, prev_page_token):
        """Sets the prev_page_token of this VolumeConfigurationListResponse.

        PageToken for the previous paged list  # noqa: E501

        :param prev_page_token: The prev_page_token of this VolumeConfigurationListResponse.  # noqa: E501
        :type: str
        """

        self._prev_page_token = prev_page_token

    @property
    def last_page_token(self):
        """Gets the last_page_token of this VolumeConfigurationListResponse.  # noqa: E501

        PageToken for the last paged list. Only included when totalItemCount is listed  # noqa: E501

        :return: The last_page_token of this VolumeConfigurationListResponse.  # noqa: E501
        :rtype: str
        """
        return self._last_page_token

    @last_page_token.setter
    def last_page_token(self, last_page_token):
        """Sets the last_page_token of this VolumeConfigurationListResponse.

        PageToken for the last paged list. Only included when totalItemCount is listed  # noqa: E501

        :param last_page_token: The last_page_token of this VolumeConfigurationListResponse.  # noqa: E501
        :type: str
        """

        self._last_page_token = last_page_token

    @property
    def total_item_count(self):
        """Gets the total_item_count of this VolumeConfigurationListResponse.  # noqa: E501

        Total number of items in all pages. Only included when requested  # noqa: E501

        :return: The total_item_count of this VolumeConfigurationListResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_item_count

    @total_item_count.setter
    def total_item_count(self, total_item_count):
        """Sets the total_item_count of this VolumeConfigurationListResponse.

        Total number of items in all pages. Only included when requested  # noqa: E501

        :param total_item_count: The total_item_count of this VolumeConfigurationListResponse.  # noqa: E501
        :type: int
        """

        self._total_item_count = total_item_count

    @property
    def total_page_count(self):
        """Gets the total_page_count of this VolumeConfigurationListResponse.  # noqa: E501

        Total number of pages. Only included when totalItemCount is listed  # noqa: E501

        :return: The total_page_count of this VolumeConfigurationListResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_page_count

    @total_page_count.setter
    def total_page_count(self, total_page_count):
        """Sets the total_page_count of this VolumeConfigurationListResponse.

        Total number of pages. Only included when totalItemCount is listed  # noqa: E501

        :param total_page_count: The total_page_count of this VolumeConfigurationListResponse.  # noqa: E501
        :type: int
        """

        self._total_page_count = total_page_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VolumeConfigurationListResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VolumeConfigurationListResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from libica.openapi.libtes.models.agent_task_run import AgentTaskRun
from libica.openapi.libtes.models.check_out_queued_task_run_request import CheckOutQueuedTaskRunRequest
from libica.openapi.libtes.models.cluster import Cluster
from libica.openapi.libtes.models.cluster_summary import ClusterSummary
from libica.openapi.libtes.models.cluster_summary_paged_items import ClusterSummaryPagedItems
from libica.openapi.libtes.models.container_state import ContainerState
from libica.openapi.libtes.models.container_state_running import ContainerStateRunning
from libica.openapi.libtes.models.container_state_terminated import ContainerStateTerminated
from libica.openapi.libtes.models.container_state_waiting import ContainerStateWaiting
from libica.openapi.libtes.models.container_status import ContainerStatus
from libica.openapi.libtes.models.create_cluster_request import CreateClusterRequest
from libica.openapi.libtes.models.create_task_request import CreateTaskRequest
from libica.openapi.libtes.models.create_task_run_request import CreateTaskRunRequest
from libica.openapi.libtes.models.create_task_version_request import CreateTaskVersionRequest
from libica.openapi.libtes.models.credentials import Credentials
from libica.openapi.libtes.models.environment import Environment
from libica.openapi.libtes.models.error_response import ErrorResponse
from libica.openapi.libtes.models.execution import Execution
from libica.openapi.libtes.models.heartbeat_task_run_request import HeartbeatTaskRunRequest
from libica.openapi.libtes.models.image import Image
from libica.openapi.libtes.models.input_mount_mapping_with_creds import InputMountMappingWithCreds
from libica.openapi.libtes.models.input_stream_settings import InputStreamSettings
from libica.openapi.libtes.models.launch_task_request import LaunchTaskRequest
from libica.openapi.libtes.models.mount_mapping_with_creds import MountMappingWithCreds
from libica.openapi.libtes.models.resources import Resources
from libica.openapi.libtes.models.system_files import SystemFiles
from libica.openapi.libtes.models.task import Task
from libica.openapi.libtes.models.task_run import TaskRun
from libica.openapi.libtes.models.task_run_heartbeat import TaskRunHeartbeat
from libica.openapi.libtes.models.task_run_logs import TaskRunLogs
from libica.openapi.libtes.models.task_run_summary import TaskRunSummary
from libica.openapi.libtes.models.task_run_summary_paged_items import TaskRunSummaryPagedItems
from libica.openapi.libtes.models.task_summary import TaskSummary
from libica.openapi.libtes.models.task_summary_paged_items import TaskSummaryPagedItems
from libica.openapi.libtes.models.task_version import TaskVersion
from libica.openapi.libtes.models.task_version_summary import TaskVersionSummary
from libica.openapi.libtes.models.task_version_summary_paged_items import TaskVersionSummaryPagedItems
from libica.openapi.libtes.models.update_cluster_request import UpdateClusterRequest
from libica.openapi.libtes.models.update_task_request import UpdateTaskRequest
from libica.openapi.libtes.models.update_task_run_state_request import UpdateTaskRunStateRequest
from libica.openapi.libtes.models.update_task_version_request import UpdateTaskVersionRequest



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class CreateFileRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'volume_id': 'str',
        'folder_path': 'str',
        'type': 'str',
        'volume_name': 'str',
        'format': 'str',
        'format_edam': 'str',
        'metadata': 'object'
    }

    attribute_map = {
        'name': 'name',
        'volume_id': 'volumeId',
        'folder_path': 'folderPath',
        'type': 'type',
        'volume_name': 'volumeName',
        'format': 'format',
        'format_edam': 'formatEdam',
        'metadata': 'metadata'
    }

    def __init__(self, name=None, volume_id=None, folder_path=None, type=None, volume_name=None, format=None, format_edam=None, metadata=None, local_vars_configuration=None):  # noqa: E501
        """CreateFileRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._volume_id = None
        self._folder_path = None
        self._type = None
        self._volume_name = None
        self._format = None
        self._format_edam = None
        self._metadata = None
        self.discriminator = None

        self.name = name
        if volume_id is not None:
            self.volume_id = volume_id
        if folder_path is not None:
            self.folder_path = folder_path
        if type is not None:
            self.type = type
        if volume_name is not None:
            self.volume_name = volume_name
        if format is not None:
            self.format = format
        if format_edam is not None:
            self.format_edam = format_edam
        if metadata is not None:
            self.metadata = metadata

    @property
    def name(self):
        """Gets the name of this CreateFileRequest.  # noqa: E501

        Name of the file to be uploaded, case sensitive.  # noqa: E501

        :return: The name of this CreateFileRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateFileRequest.

        Name of the file to be uploaded, case sensitive.  # noqa: E501

        :param name: The name of this CreateFileRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and not re.search(r'^[^\/]+$', name)):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^[^\/]+$/`")  # noqa: E501

        self._name = name

    @property
    def volume_id(self):
        """Gets the volume_id of this CreateFileRequest.  # noqa: E501

        Volume ID to which the file will be uploaded  # noqa: E501

        :return: The volume_id of this CreateFileRequest.  # noqa: E501
        :rtype: str
        """
        return self._volume_id

    @volume_id.setter
    def volume_id(self, volume_id):
        """Sets the volume_id of this CreateFileRequest.

        Volume ID to which the file will be uploaded  # noqa: E501

        :param volume_id: The volume_id of this CreateFileRequest.  # noqa: E501
        :type: str
        """

        self._volume_id = volume_id

    @property
    def folder_path(self):
        """Gets the folder_path of this CreateFileRequest.  # noqa: E501

        Optional folder path where the file will be uploaded to  # noqa: E501

        :return: The folder_path of this CreateFileRequest.  # noqa: E501
        :rtype: str
        """
        return self._folder_path

    @folder_path.setter
    def folder_path(self, folder_path):
        """Sets the folder_path of this CreateFileRequest.

        Optional folder path where the file will be uploaded to  # noqa: E501

        :param folder_path: The folder_path of this CreateFileRequest.  # noqa: E501
        :type: str
        """

        self._folder_path = folder_path

    @property
    def type(self):
        """Gets the type of this CreateFileRequest.  # noqa: E501

        Optional file content type, e.g. text/plain, application/json  # noqa: E501

        :return: The type of this CreateFileRequest.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateFileRequest.

        Optional file content type, e.g. text/plain, application/json  # noqa: E501

        :param type: The type of this CreateFileRequest.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def volume_name(self):
        """Gets the volume_name of this CreateFileRequest.  # noqa: E501

        Name of the Volume  # noqa: E501

        :return: The volume_name of this CreateFileRequest.  # noqa: E501
        :rtype: str
        """
        return self._volume_name

    @volume_name.setter
    def volume_name(self, volume_name):
        """Sets the volume_name of this CreateFileRequest.

        Name of the Volume  # noqa: E501

        :param volume_name: The volume_name of this CreateFileRequest.  # noqa: E501
        :type: str
        """

        self._volume_name = volume_name

    @property
    def format(self):
        """Gets the format of this CreateFileRequest.  # noqa: E501

        The File's Format  # noqa: E501

        :return: The format of this CreateFileRequest.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this CreateFileRequest.

        The File's Format  # noqa: E501

        :param format: The format of this CreateFileRequest.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def format_edam(self):
        """Gets the format_edam of this CreateFileRequest.  # noqa: E501

        The File's Edam Format  # noqa: E501

        :return: The format_edam of this CreateFileRequest.  # noqa: E501
        :rtype: str
        """
        return self._format_edam

    @format_edam.setter
    def format_edam(self, format_edam):
        """Sets the format_edam of this CreateFileRequest.

        The File's Edam Format  # noqa: E501

        :param format_edam: The format_edam of this CreateFileRequest.  # noqa: E501
        :type: str
        """

        self._format_edam = format_edam

    @property
    def metadata(self):
        """Gets the metadata of this CreateFileRequest.  # noqa: E501

        Metadata about this file and its contents  # noqa: E501

        :return: The metadata of this CreateFileRequest.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this CreateFileRequest.

        Metadata about this file and its contents  # noqa: E501

        :param metadata: The metadata of this CreateFileRequest.  # noqa: E501
        :type: object
        """

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateFileRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateFileRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class BulkMetadataUpdateOperationParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'folder_id': 'str',
        'folder_path': 'str',
        'volume_id': 'str',
        'file_status': 'str',
        'parent_folder_metadata_updates': 'MetadataUpdateRequest',
        'children_folders_updates': 'MetadataUpdateRequest',
        'children_files_updates': 'MetadataUpdateRequest'
    }

    attribute_map = {
        'folder_id': 'folderId',
        'folder_path': 'folderPath',
        'volume_id': 'volumeId',
        'file_status': 'fileStatus',
        'parent_folder_metadata_updates': 'parentFolderMetadataUpdates',
        'children_folders_updates': 'childrenFoldersUpdates',
        'children_files_updates': 'childrenFilesUpdates'
    }

    def __init__(self, folder_id=None, folder_path=None, volume_id=None, file_status=None, parent_folder_metadata_updates=None, children_folders_updates=None, children_files_updates=None, local_vars_configuration=None):  # noqa: E501
        """BulkMetadataUpdateOperationParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._folder_id = None
        self._folder_path = None
        self._volume_id = None
        self._file_status = None
        self._parent_folder_metadata_updates = None
        self._children_folders_updates = None
        self._children_files_updates = None
        self.discriminator = None

        if folder_id is not None:
            self.folder_id = folder_id
        if folder_path is not None:
            self.folder_path = folder_path
        if volume_id is not None:
            self.volume_id = volume_id
        if file_status is not None:
            self.file_status = file_status
        if parent_folder_metadata_updates is not None:
            self.parent_folder_metadata_updates = parent_folder_metadata_updates
        if children_folders_updates is not None:
            self.children_folders_updates = children_folders_updates
        if children_files_updates is not None:
            self.children_files_updates = children_files_updates

    @property
    def folder_id(self):
        """Gets the folder_id of this BulkMetadataUpdateOperationParameters.  # noqa: E501


        :return: The folder_id of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :rtype: str
        """
        return self._folder_id

    @folder_id.setter
    def folder_id(self, folder_id):
        """Sets the folder_id of this BulkMetadataUpdateOperationParameters.


        :param folder_id: The folder_id of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :type: str
        """

        self._folder_id = folder_id

    @property
    def folder_path(self):
        """Gets the folder_path of this BulkMetadataUpdateOperationParameters.  # noqa: E501


        :return: The folder_path of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :rtype: str
        """
        return self._folder_path

    @folder_path.setter
    def folder_path(self, folder_path):
        """Sets the folder_path of this BulkMetadataUpdateOperationParameters.


        :param folder_path: The folder_path of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :type: str
        """

        self._folder_path = folder_path

    @property
    def volume_id(self):
        """Gets the volume_id of this BulkMetadataUpdateOperationParameters.  # noqa: E501


        :return: The volume_id of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :rtype: str
        """
        return self._volume_id

    @volume_id.setter
    def volume_id(self, volume_id):
        """Sets the volume_id of this BulkMetadataUpdateOperationParameters.


        :param volume_id: The volume_id of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :type: str
        """

        self._volume_id = volume_id

    @property
    def file_status(self):
        """Gets the file_status of this BulkMetadataUpdateOperationParameters.  # noqa: E501


        :return: The file_status of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :rtype: str
        """
        return self._file_status

    @file_status.setter
    def file_status(self, file_status):
        """Sets the file_status of this BulkMetadataUpdateOperationParameters.


        :param file_status: The file_status of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :type: str
        """

        self._file_status = file_status

    @property
    def parent_folder_metadata_updates(self):
        """Gets the parent_folder_metadata_updates of this BulkMetadataUpdateOperationParameters.  # noqa: E501


        :return: The parent_folder_metadata_updates of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :rtype: MetadataUpdateRequest
        """
        return self._parent_folder_metadata_updates

    @parent_folder_metadata_updates.setter
    def parent_folder_metadata_updates(self, parent_folder_metadata_updates):
        """Sets the parent_folder_metadata_updates of this BulkMetadataUpdateOperationParameters.


        :param parent_folder_metadata_updates: The parent_folder_metadata_updates of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :type: MetadataUpdateRequest
        """

        self._parent_folder_metadata_updates = parent_folder_metadata_updates

    @property
    def children_folders_updates(self):
        """Gets the children_folders_updates of this BulkMetadataUpdateOperationParameters.  # noqa: E501


        :return: The children_folders_updates of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :rtype: MetadataUpdateRequest
        """
        return self._children_folders_updates

    @children_folders_updates.setter
    def children_folders_updates(self, children_folders_updates):
        """Sets the children_folders_updates of this BulkMetadataUpdateOperationParameters.


        :param children_folders_updates: The children_folders_updates of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :type: MetadataUpdateRequest
        """

        self._children_folders_updates = children_folders_updates

    @property
    def children_files_updates(self):
        """Gets the children_files_updates of this BulkMetadataUpdateOperationParameters.  # noqa: E501


        :return: The children_files_updates of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :rtype: MetadataUpdateRequest
        """
        return self._children_files_updates

    @children_files_updates.setter
    def children_files_updates(self, children_files_updates):
        """Sets the children_files_updates of this BulkMetadataUpdateOperationParameters.


        :param children_files_updates: The children_files_updates of this BulkMetadataUpdateOperationParameters.  # noqa: E501
        :type: MetadataUpdateRequest
        """

        self._children_files_updates = children_files_updates

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BulkMetadataUpdateOperationParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BulkMetadataUpdateOperationParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libwes.configuration import Configuration


class WorkflowRunHistoryEvent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'event_id': 'int',
        'previous_event_id': 'int',
        'event_type': 'str',
        'timestamp': 'datetime',
        'event_details': 'object'
    }

    attribute_map = {
        'name': 'name',
        'event_id': 'eventId',
        'previous_event_id': 'previousEventId',
        'event_type': 'eventType',
        'timestamp': 'timestamp',
        'event_details': 'eventDetails'
    }

    def __init__(self, name=None, event_id=None, previous_event_id=None, event_type=None, timestamp=None, event_details=None, local_vars_configuration=None):  # noqa: E501
        """WorkflowRunHistoryEvent - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._event_id = None
        self._previous_event_id = None
        self._event_type = None
        self._timestamp = None
        self._event_details = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if event_id is not None:
            self.event_id = event_id
        if previous_event_id is not None:
            self.previous_event_id = previous_event_id
        if event_type is not None:
            self.event_type = event_type
        if timestamp is not None:
            self.timestamp = timestamp
        if event_details is not None:
            self.event_details = event_details

    @property
    def name(self):
        """Gets the name of this WorkflowRunHistoryEvent.  # noqa: E501

        Name of the event, such as the name of the step/task for state-level events and run name for run-level events  # noqa: E501

        :return: The name of this WorkflowRunHistoryEvent.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkflowRunHistoryEvent.

        Name of the event, such as the name of the step/task for state-level events and run name for run-level events  # noqa: E501

        :param name: The name of this WorkflowRunHistoryEvent.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def event_id(self):
        """Gets the event_id of this WorkflowRunHistoryEvent.  # noqa: E501

        Identifier for the history event, if any  # noqa: E501

        :return: The event_id of this WorkflowRunHistoryEvent.  # noqa: E501
        :rtype: int
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this WorkflowRunHistoryEvent.

        Identifier for the history event, if any  # noqa: E501

        :param event_id: The event_id of this WorkflowRunHistoryEvent.  # noqa: E501
        :type: int
        """

        self._event_id = event_id

    @property
    def previous_event_id(self):
        """Gets the previous_event_id of this WorkflowRunHistoryEvent.  # noqa: E501

        Identifier for any previous history event (if available)  # noqa: E501

        :return: The previous_event_id of this WorkflowRunHistoryEvent.  # noqa: E501
        :rtype: int
        """
        return self._previous_event_id

    @previous_event_id.setter
    def previous_event_id(self, previous_event_id):
        """Sets the previous_event_id of this WorkflowRunHistoryEvent.

        Identifier for any previous history event (if available)  # noqa: E501

        :param previous_event_id: The previous_event_id of this WorkflowRunHistoryEvent.  # noqa: E501
        :type: int
        """

        self._previous_event_id = previous_event_id

    @property
    def event_type(self):
        """Gets the event_type of this WorkflowRunHistoryEvent.  # noqa: E501

        Type of history event. The associated details entry will be populated based on the type of event.  # noqa: E501

        :return: The event_type of this WorkflowRunHistoryEvent.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this WorkflowRunHistoryEvent.

        Type of history event. The associated details entry will be populated based on the type of event.  # noqa: E501

        :param event_type: The event_type of this WorkflowRunHistoryEvent.  # noqa: E501
        :type: str
        """

        self._event_type = event_type

    @property
    def timestamp(self):
        """Gets the timestamp of this WorkflowRunHistoryEvent.  # noqa: E501

        Timestamp for the history event  # noqa: E501

        :return: The timestamp of this WorkflowRunHistoryEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this WorkflowRunHistoryEvent.

        Timestamp for the history event  # noqa: E501

        :param timestamp: The timestamp of this WorkflowRunHistoryEvent.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    @property
    def event_details(self):
        """Gets the event_details of this WorkflowRunHistoryEvent.  # noqa: E501

        Details for history event  # noqa: E501

        :return: The event_details of this WorkflowRunHistoryEvent.  # noqa: E501
        :rtype: object
        """
        return self._event_details

    @event_details.setter
    def event_details(self, event_details):
        """Sets the event_details of this WorkflowRunHistoryEvent.

        Details for history event  # noqa: E501

        :param event_details: The event_details of this WorkflowRunHistoryEvent.  # noqa: E501
        :type: object
        """

        self._event_details = event_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowRunHistoryEvent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowRunHistoryEvent):
            return True

        return self.to_dict() != other.to_dict()
